@@ -9,14 +9,16 @@ def prepare_job(session: requests.Session, url: str,
                 successful_states: [str],
                 waiting_states: [str],
                 extra_params: dict = {}, extra_headers: dict = {},
-                wait_delay_seconds=5):
+                wait_delay_seconds=5,
+                timeout=(10, 60),
+                ):
     logger = logging.getLogger(__name__)
     requestHeaders = {
         "Content-type": "application/json",
         "Accept": "application/json",
         **extra_headers
     }
-    response = session.post(url, headers=requestHeaders, json={**extra_params})
+    response = session.post(url, headers=requestHeaders, json={**extra_params}, timeout=timeout)
     response.raise_for_status()
 
     job_id = response.json()[response_job_id_field_name]
@@ -24,7 +26,7 @@ def prepare_job(session: requests.Session, url: str,
     state_response_json = None
     while state in waiting_states:
         time.sleep(wait_delay_seconds)
-        state_response = session.get(f"{url}/{job_id}", headers=requestHeaders)
+        state_response = session.get(f"{url}/{job_id}", headers=requestHeaders, timeout=timeout)
         state_response_json = state_response.json()
         logger.debug(state_response_json)
         state = state_response_json[response_state_field_name]
